# *pydmt* project by Mark Veltzer

description: Python dependency management tool

project website: https://veltzer.github.io/pydmt

author: Mark Veltzer

version: 0.3.30

![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)

## github

![License](https://img.shields.io/github/license/veltzer/pydmt)

## build

![build](https://github.com/veltzer/pydmt/workflows/build/badge.svg)

## pypi

![PyPI - Status](https://img.shields.io/pypi/status/pydmt)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pydmt)
![PyPI - License](https://img.shields.io/pypi/l/pydmt)
![PyPI - Package Name](https://img.shields.io/pypi/v/pydmt)
![PyPI - Format](https://img.shields.io/pypi/format/pydmt)

## pypi download

![PyPI - Downloads](https://img.shields.io/pypi/dd/pydmt)
![PyPI - Downloads](https://img.shields.io/pypi/dw/pydmt)
![PyPI - Downloads](https://img.shields.io/pypi/dm/pydmt)



## contact me
[mailto](mailto:mark.veltzer@gmail.com)
![gitter](https://img.shields.io/gitter/room/veltzer/mark.veltzer)
![discord](https://img.shields.io/discord/719336281624281119)
![discord](https://img.shields.io/discord/719336282194444302)

Mark Veltzer, Copyright © 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024, 2025
